==> zio-aws-mediatailor_3-5.17.103.1-sources.jar: zio/aws/mediatailor/model/GetChannelScheduleResponse.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetChannelScheduleResponse(
    items: Option[Iterable[zio.aws.mediatailor.model.ScheduleEntry]] = None,
    nextToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.GetChannelScheduleResponse = {
    import GetChannelScheduleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.GetChannelScheduleResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(
        nextToken.map(value => __string.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.GetChannelScheduleResponse.ReadOnly =
    zio.aws.mediatailor.model.GetChannelScheduleResponse.wrap(buildAwsValue())
}
object GetChannelScheduleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.GetChannelScheduleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.GetChannelScheduleResponse =
      zio.aws.mediatailor.model.GetChannelScheduleResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items: Option[List[zio.aws.mediatailor.model.ScheduleEntry.ReadOnly]]
    def nextToken: Option[__string]
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.mediatailor.model.ScheduleEntry.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.GetChannelScheduleResponse
  ) extends zio.aws.mediatailor.model.GetChannelScheduleResponse.ReadOnly {
    override val items
        : Option[List[zio.aws.mediatailor.model.ScheduleEntry.ReadOnly]] = scala
      .Option(impl.items())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.mediatailor.model.ScheduleEntry.wrap(item)
        }.toList
      )
    override val nextToken: Option[__string] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.mediatailor.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.GetChannelScheduleResponse
  ): zio.aws.mediatailor.model.GetChannelScheduleResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.158.3-sources.jar: zio/aws/mediatailor/model/GetChannelScheduleResponse.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetChannelScheduleResponse(
    items: Option[Iterable[zio.aws.mediatailor.model.ScheduleEntry]] = None,
    nextToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.GetChannelScheduleResponse = {
    import GetChannelScheduleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.GetChannelScheduleResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.GetChannelScheduleResponse.ReadOnly =
    zio.aws.mediatailor.model.GetChannelScheduleResponse.wrap(buildAwsValue())
}
object GetChannelScheduleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.GetChannelScheduleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.GetChannelScheduleResponse =
      zio.aws.mediatailor.model.GetChannelScheduleResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items: Option[List[zio.aws.mediatailor.model.ScheduleEntry.ReadOnly]]
    def nextToken: Option[__string]
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.mediatailor.model.ScheduleEntry.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.GetChannelScheduleResponse
  ) extends zio.aws.mediatailor.model.GetChannelScheduleResponse.ReadOnly {
    override val items
        : Option[List[zio.aws.mediatailor.model.ScheduleEntry.ReadOnly]] = scala
      .Option(impl.items())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.mediatailor.model.ScheduleEntry.wrap(item)
        }.toList
      )
    override val nextToken: Option[__string] =
      scala.Option(impl.nextToken()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.GetChannelScheduleResponse
  ): zio.aws.mediatailor.model.GetChannelScheduleResponse.ReadOnly =
    new Wrapper(impl)
}
